@@ -1,7 +1,7 @@
 //
 // admiral.cpp
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -46,6 +46,12 @@ void AdmiralTV1::populateProtocol(
 
   threadableProtocol = new SharpProtocol(guiObject, index, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   addSharpKey("tv-1", One_Key, 0x01, 0x01);
   addSharpKey("tv-2", Two_Key, 0x01, 0x02);
   addSharpKey("tv-3", Three_Key, 0x01, 0x03);
@@ -95,6 +101,12 @@ void AdmiralTV2::populateProtocol(
 
   threadableProtocol = new RC5Protocol(guiObject, index);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   addKey("0", Zero_Key, 0x1000, 13);
   addKey("1", One_Key, 0x1001, 13);
   addKey("2", Two_Key, 0x1002, 13);
@@ -165,6 +177,12 @@ void AdmiralVCR1::populateProtocol(
 
   threadableProtocol = new SharpProtocol(guiObject, index, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   addSharpKey("vcr-1", One_Key, 0x03, 0x01);
   addSharpKey("vcr-2", Two_Key, 0x03, 0x02);
   addSharpKey("vcr-3", Three_Key, 0x03, 0x03);
