@@ -1,7 +1,7 @@
 //
 // audiosonic.cpp
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -45,5 +45,11 @@ void AudiosonicTV::populateProtocol(
 
   threadableProtocol = new PanasonicOldProtocol(guiObject, index);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   addPanOldKey(
 }
