@@ -1,7 +1,7 @@
 //
 // cambridge.h
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -25,11 +25,12 @@
 
 #include "pirkeysetmetadata.h"
 
-class QObject;
 class QComboBox;
 
 class CambridgeCD1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   CambridgeCD1(
     unsigned int index);
@@ -40,6 +41,8 @@ public:
 
 class CambridgeAudio1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   CambridgeAudio1(
     unsigned int index);
@@ -50,6 +53,8 @@ public:
 
 class CambridgeAudio2: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   CambridgeAudio2(
     unsigned int index);
@@ -63,6 +68,8 @@ public:
 
 class CambridgeAudio3: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   CambridgeAudio3(
     unsigned int index);
@@ -76,6 +83,8 @@ public:
 
 class CambridgeDVD1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   CambridgeDVD1(
     unsigned int index);
