@@ -1,7 +1,7 @@
 //
 // crown.h
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -25,11 +25,12 @@
 
 #include "pirkeysetmetadata.h"
 
-class QObject;
 class QComboBox;
 
 class CrownTV1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   CrownTV1(
     unsigned int index);
@@ -43,6 +44,8 @@ public:
 
 class CrownAudio1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   CrownAudio1(
     unsigned int index);
