@@ -1,7 +1,7 @@
 //
 // goldstar.cpp
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -50,6 +50,12 @@ void GoldStarTV1::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x04, 8);
 
   addKey("prup", ChannelUp_Key, 0x00, 8);
@@ -106,6 +112,12 @@ void GoldStarTV2::populateProtocol(
 
   threadableProtocol = new RC5Protocol(guiObject, index, 0x40);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   addKey("0", Zero_Key, 0x00, 6);
   addKey("1", One_Key, 0x01, 6);
   addKey("2", Two_Key, 0x02, 6);
@@ -170,6 +182,12 @@ void GoldStarVCR1::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
 //  setPreData(0x7689, 16);
   setPreData(0x6E, 8);
 
@@ -319,6 +337,12 @@ void GoldStarAudio1::populateProtocol(
 
   threadableProtocol = new NECXProtocol(guiObject, index, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x1010, 16);
 
   addKey("fm", FM_Key, 0x00, 8);
