@@ -1,7 +1,7 @@
 //
 // ilo.h
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -25,11 +25,12 @@
 
 #include "pirkeysetmetadata.h"
 
-class QObject;
 class QComboBox;
 
 class ILOTV1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   ILOTV1(
     unsigned int index);
@@ -44,6 +45,8 @@ public:
 
 class ILOTV2: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   ILOTV2(
     unsigned int index);
@@ -55,6 +58,8 @@ public:
 
 class ILOTV3: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   ILOTV3(
     unsigned int index);
