@@ -1,7 +1,7 @@
 //
 // onkyo.cpp
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -48,6 +48,12 @@ void OnkyoAudio1::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0xD2, 8);
 
   addKey("PLAY", Play_Key, 0x49, 8);
@@ -99,6 +105,12 @@ void OnkyoAudio2::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, true, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x0DD2, 16);
 
   addKey("Autospace", Unmapped_Key, 0x1B, 8);
@@ -188,6 +200,12 @@ void OnkyoAudio3::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, true, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x6DD2, 16);
 
   addKey("tuner_:_preset_>", NextPreset_Key, 0x00, 8);
@@ -298,6 +316,12 @@ void OnkyoAudio4::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, true, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x2CD2, 16);
 
   addKey("CD_FWD", FastForward_Key, 0x00, 8);
@@ -363,6 +387,12 @@ void OnkyoAudio5::populateProtocol(
 
   threadableProtocol = new KaseikyoProtocol(guiObject, index);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x2002, 16);
 
   addKaseikyoKey("Stop", Stop_Key, 0x0AA, 0x00);
@@ -419,6 +449,12 @@ void OnkyoDVD1::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, true, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x6CD2, 16);
 
   addKey("mdfastforward", Unmapped_Key, 0x00, 8);
@@ -500,6 +536,12 @@ void OnkyoDVD2::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, true, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x2BD2, 16);
 
   addKey("Power", Power_Key, 0x04, 8);
