@@ -1,7 +1,7 @@
 //
 // panasonic.cpp
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -49,6 +49,12 @@ void PanasonicCarAudio::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, true, false);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
 //  setPreData(0x8156, 16);
   setPreData(0x6A81, 16);
 
@@ -85,6 +91,12 @@ void PanasonicSat1::populateProtocol(
 
   threadableProtocol = new PanasonicProtocol(guiObject, index);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
 //  setPreData(0x40040140, 32);
   setPreData(0x2002, 16);
 
@@ -176,6 +188,12 @@ void PanasonicTV1::populateProtocol(
 
   threadableProtocol = new PanasonicProtocol(guiObject, index);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x2002, 16);
 
   addPanasonicKey("Video 1", VideoInput_Key, 0x80, 0x00, 0x01);
@@ -410,6 +428,12 @@ void PanasonicTV2::populateProtocol(
 
   threadableProtocol = new PanasonicOldProtocol(guiObject, index);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   addPanOldKey("Mute", Mute_Key, 0x00, 0x00);
   addPanOldKey("R-Tune", Unmapped_Key, 0x00, 0x0A);
   addPanOldKey("Sleep", Sleep_Key, 0x00, 0x0B);
@@ -499,6 +523,12 @@ void PanasonicVCR1::populateProtocol(
 
   threadableProtocol = new PanasonicProtocol(guiObject, index);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
 //  setPreData(0x400409, 24);
   setPreData(0x2002, 16);
 
@@ -691,6 +721,12 @@ void PanasonicVCR2::populateProtocol(
 
   threadableProtocol = new PanasonicOldProtocol(guiObject, index);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   addPanOldKey("STOP", Stop_Key, 0x02, 0x00);
   addPanOldKey("REW", Rewind_Key, 0x02, 0x02);
   addPanOldKey("FF", FastForward_Key, 0x02, 0x03);
@@ -759,6 +795,12 @@ void PanasonicDVD1::populateProtocol(
 
   threadableProtocol = new PanasonicProtocol(guiObject, index);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
 //  setPreData(0x40040D00, 32);
   setPreData(0x2002, 16);
 
@@ -887,6 +929,12 @@ void PanasonicAudio1::populateProtocol(
 
   threadableProtocol = new PanasonicProtocol(guiObject, index);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
 //  setPreData(0x40040543, 32);
   setPreData(0x2002, 16);
 
@@ -988,6 +1036,12 @@ void PanasonicAudio2::populateProtocol(
 
   threadableProtocol = new PanasonicProtocol(guiObject, index);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x2002, 16);
 
   addPanasonicKey("Volume_Up", VolumeUp_Key, 0xA0, 0x00, 0x20);
@@ -1102,6 +1156,12 @@ void PanasonicAudio3::populateProtocol(
 
   threadableProtocol = new PanasonicOldProtocol(guiObject, index);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   addPanOldKey("audio_power", Power_Key, 0x09, 0x20);
   addPanOldKey("audio_phono", PhonoInput_Key, 0x09, 0x0C);
   addPanOldKey("vol-", VolumeDown_Key, 0x09, 0x25);
@@ -1168,6 +1228,12 @@ void PanasonicAC1::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, true, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x6681, 16);
 
   addKey("Operation", Power_Key, 0x81, 8);
