@@ -1,7 +1,7 @@
 //
 // sanyo.cpp
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -49,6 +49,12 @@ void SanyoVCR1::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
 //  setPreData(0x8C73, 16);
   setPreData(0x31, 8);
 
@@ -123,6 +129,12 @@ void SanyoDVD1::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, true, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
 //  setPreData(0x3C23, 16);
   setPreData(0xC43C, 16);
 
@@ -195,6 +207,12 @@ void SanyoTV1::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x38, 8);
 
   addKey("0", Zero_Key, 0x00, 8);
@@ -371,6 +389,12 @@ void SanyoTV2::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x38, 8);
 
   addKey("0", Zero_Key, 0x00, 8);
@@ -461,6 +485,12 @@ void SanyoProjector1::populateProtocol(
   // Need to set the protocol to use 16-bit predata, for child keysets:
   threadableProtocol = new NECProtocol(guiObject, index, true, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0xCF30, 16);
 
   addKey("Power", Power_Key, 0x00, 8); //"ONOFF0"
