@@ -1,7 +1,7 @@
 //
 // sinotec.h
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -25,10 +25,11 @@
 
 #include "pirkeysetmetadata.h"
 
-class QObject;
 
 class SinotecTV1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   SinotecTV1(
     unsigned int index);
@@ -39,6 +40,8 @@ public:
 
 class SinotecTV2: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   SinotecTV2(
     unsigned int index);
