@@ -1,7 +1,7 @@
 //
 // sky.cpp
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -45,6 +45,12 @@ void SkyReceiver1::populateProtocol(
 
   threadableProtocol = new RC6SkyProtocol(guiObject, index);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x000, 12);
 
   addKey("0", Zero_Key, 0x00, 8);
