@@ -1,7 +1,7 @@
 //
 // strong.cpp
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2013 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -49,6 +49,12 @@ void StrongSat1::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, true, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x7780, 16);
 
   addKey("POWER", Power_Key, 0x16, 8);
@@ -121,6 +127,12 @@ void StrongSat2::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x01, 8);
 
   addKey("power", Power_Key, 0x00, 8);
@@ -228,6 +240,12 @@ void StrongSat3::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, true, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x0202, 16);
 
   addKey("0", Zero_Key, 0x00, 8);
@@ -346,6 +364,12 @@ void StrongSat4::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x00, 8);
 
   addKey("Mute", Mute_Key, 0x00, 8);
@@ -426,6 +450,12 @@ void StrongSat5::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, true, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0xF0FF, 16);
 
   addKey("0", Zero_Key, 0x00, 8);
@@ -539,6 +569,12 @@ void StrongSTB1::populateProtocol(
 
   threadableProtocol = new RECS80Protocol(guiObject, index);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x5, 3);
 
   addKey("display/info", Info_Key, 0x14, 6);
@@ -599,6 +635,12 @@ void StrongSTB2::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, true, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x0820, 16);
 
   addKey("STAND BY", Power_Key, 0x00, 8);
@@ -684,6 +726,12 @@ void StrongSTB3::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x00, 8);
 
   addKey("power", Power_Key, 0x00, 8);
@@ -744,6 +792,12 @@ void StrongSTB4::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0xC0, 8);
 
   addKey("program guide", Guide_Key, 0x80, 8);
@@ -815,6 +869,12 @@ void StrongSTB5::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x00, 8);
 
   addKey("Page-", PageDown_Key, 0x00, 8);
