@@ -1,7 +1,7 @@
 //
 // sylvania.h
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -25,10 +25,11 @@
 
 #include "pirkeysetmetadata.h"
 
-class QObject;
 
 class SylvaniaTV1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   SylvaniaTV1(
     unsigned int index);
@@ -40,6 +41,8 @@ public:
 
 class SylvaniaFan1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   SylvaniaFan1(
     unsigned int index);
