@@ -1,7 +1,7 @@
 //
 // toshiba.cpp
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -48,6 +48,12 @@ void ToshibaTV1::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x40, 8);
 
   addKey("0", Zero_Key, 0x00, 8);
@@ -387,6 +393,12 @@ void ToshibaVCR1::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x44, 8);
 
   addKey("1", One_Key, 0x01, 8);
@@ -529,6 +541,12 @@ void ToshibaDisc1::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x45, 8);
 
   addKey("pause", Pause_Key, 0x00, 8);
@@ -713,6 +731,12 @@ void ToshibaDisc2::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, true, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0xBC45, 16);
 
   addKey("1", One_Key, 0x01, 8);
@@ -829,6 +853,12 @@ void ToshibaProjector1::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, true, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x0AE7, 16);
 
   addKey("video", AuxInput_Key, 0x0B, 8);
@@ -878,6 +908,12 @@ void ToshibaSTB1::populateProtocol(
 
   threadableProtocol = new NECProtocol(guiObject, index, false, true);
 
+  connect(
+    threadableProtocol,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   setPreData(0x42, 8);
 
   addKey("num 1 / G (Galaxy/G-Star)", One_Key, 0x81, 8);
