@@ -1,7 +1,7 @@
 //
 // venturer.h
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -25,10 +25,11 @@
 
 #include "pirkeysetmetadata.h"
 
-class QObject;
 
 class VenturerTV1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   VenturerTV1(
     unsigned int index);
@@ -39,6 +40,8 @@ public:
 
 class VenturerDVD1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   VenturerDVD1(
     unsigned int index);
@@ -49,6 +52,8 @@ public:
 
 class VenturerSTB1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   VenturerSTB1(
     unsigned int index);
