@@ -1,7 +1,7 @@
 //
 // vestel.h
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -25,11 +25,12 @@
 
 #include "pirkeysetmetadata.h"
 
-class QObject;
 class QComboBox;
 
 class VestelTV1: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   VestelTV1(
     unsigned int index);
@@ -40,6 +41,8 @@ public:
 
 class VestelTV2: public PIRKeysetMetaData
 {
+  Q_OBJECT
+
 public:
   VestelTV2(
     unsigned int index);
