@@ -68,6 +68,7 @@
 #include "keysets/dune.h"
 #include "keysets/dynex.h"
 #include "keysets/ei.h"
+#include "keysets/elenberg.h"
 #include "keysets/elgato.h"
 #include "keysets/emerson.h"
 #include "keysets/emtec.h"
@@ -75,6 +76,7 @@
 #include "keysets/fortec.h"
 #include "keysets/foxtel.h"
 #include "keysets/frontech.h"
+#include "keysets/fujitsu.h"
 #include "keysets/gadmei.h"
 #include "keysets/generalelectric.h"
 #include "keysets/genius.h"
@@ -180,8 +182,6 @@
 #include "keysets/yamaha.h"
 #include "keysets/zenith.h"
 
-#include "pirexception.h"
-
 // Need mutex for thread support:
 #include <QMutex>
 
@@ -395,6 +395,8 @@ PIRKeysetManager::PIRKeysetManager()
   setupKeyset(new DynexTV1(++counter));
 
   setupKeyset(new EiTV1(++counter));
+  
+  setupKeyset(new Elenberg(++counter));
 
   setupKeyset(new ElgatoEyeTV1(++counter));
 
@@ -424,6 +426,8 @@ PIRKeysetManager::PIRKeysetManager()
   setupKeyset(new FrontechTV1(++counter));
   setupKeyset(new FrontechTV2(++counter));
 
+//  setupKeyset(new FujitsuAC1(++counter));
+
   setupKeyset(new GadmeiTuner1(++counter));
 
   setupKeyset(new GeneralElectricAC1(++counter));
@@ -752,7 +756,7 @@ PIRKeysetManager::PIRKeysetManager()
   setupKeyset(new PhilipsAudio2(++counter));
   setupKeyset(new PhilipsAudio3(++counter));
   setupKeyset(new PhilipsAudio4(++counter));
-//  setupKeyset(new PhilipsAudio5(++counter));
+  setupKeyset(new PhilipsAudio5(++counter));
 
   setupKeyset(new PinnaclePCTV1(++counter));
   setupKeyset(new PinnaclePCTV2(++counter));
@@ -851,6 +855,7 @@ PIRKeysetManager::PIRKeysetManager()
   setupKeyset(new SharpVCR1(++counter));
   setupKeyset(new SharpReceiver1(++counter));
   setupKeyset(new SharpAC1(++counter));
+  setupKeyset(new SharpCamcorder1(++counter));
 
   setupKeyset(new SilverCrestDVD1(++counter));
   setupKeyset(new SilverCrestDVD2(++counter));
@@ -1183,6 +1188,14 @@ void PIRKeysetManager::populateKeyset(
   }
 
   i->second->populateProtocol(guiObject);
+
+  // Set up error handling:
+  connect(
+    i->second,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
   i->second->moveToThread(&commandThread);
 }
 
