@@ -66,6 +66,7 @@ PIRMakeMgr::PIRMakeMgr()
   makes[Dune_Make] = "Dune";
   makes[Dynex_Make] = "Dynex";
   makes[Ei_Make] = "Ei";
+  makes[Elenberg_Make] = "Elenberg";
   makes[Elgato_Make] = "Elgato";
   makes[Emerson_Make] = "Emerson";
   makes[Emtec_Make] = "Emtec";
@@ -73,6 +74,7 @@ PIRMakeMgr::PIRMakeMgr()
   makes[Fortec_Make] = "Fortec Star";
   makes[Foxtel_Make] = "Foxtel";
   makes[Frontech_Make] = "Frontech";
+  makes[Fujitsu_Make] = "Fujitsu";
   makes[Gadmei_Make] = "Gadmei";
   makes[GeneralElectric_Make] = "General Electric";
   makes[Genius_Make] = "Genius";
