@@ -1,7 +1,7 @@
 //
 // rc5protocol.cpp
 //
-// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
+// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
 //
 // This file is part of Pierogi.
 //
@@ -24,7 +24,7 @@
 
 #include "pirinfraredled.h"
 
-#include "pirexception.h"
+#include <QString>
 
 #include <QMutex>
 extern bool commandInFlight;
@@ -60,96 +60,88 @@ void RC5Protocol::startSendingCommand(
   unsigned int threadableID,
   PIRKeyName command)
 {
-  // Dumping entire method inside of try/catch, to deal with cross-thread
-  // exception handling:
-  try
+  // Check if this command is meant for us:
+  if (threadableID != id) return;
+
+  clearRepeatFlag();
+
+  KeycodeCollection::const_iterator i = keycodes.find(command);
+
+  // Sanity check, make sure command exists first:
+  if (i == keycodes.end())
   {
-    // Check if this command is meant for us:
-    if (threadableID != id) return;
-
-    clearRepeatFlag();
-
-    KeycodeCollection::const_iterator i = keycodes.find(command);
-
-    // Sanity check, make sure command exists first:
-    if (i == keycodes.end())
-    {
-      QMutexLocker cifLocker(&commandIFMutex);
-      commandInFlight = false;
-      return;
-//      std::string s = "Tried to send a non-existent command.\n";
-//      throw PIRException(s);
-    }
-
-    // Construct the object that communicates with the device driver:
-    PIRInfraredLED led(carrierFrequency, dutyCycle);
-
-    int repeatCount = 0;
-    int commandDuration = 0;
-    while (repeatCount < MAX_REPEAT_COUNT)
-    {
-      // Now, throw together an RC5 protocol command string.
-
-      if (!preData.empty())
-      {
-        // For standard RC5, the "pre-data" contains the control portion,
-        // and the key contains only the 6-bit command portion.
-
-        // First, construct the control portion:
-        commandDuration += pushControlBits(led);
-
-        // Next, the key-command portion:
-        commandDuration += pushKeyCommandBits((*i).second, led);
-      }
-      else
-      {
-        // For non-standard RC5, the entire 13 bits are stuffed into the
-        // key portion, as all of them can vary:
-        commandDuration += pushNonStandardRC5((*i).second, led);
-      }
-
-      // Clear out the buffer, if necessary:
-      if (buffer)
-      {
-        led.addSingle(buffer);
-        commandDuration += buffer;
-
-        // probably unnecessary cleanup of buffer:
-        buffer = 0;
-        bufferContainsSpace = false;
-        bufferContainsPulse = false;
-      }
-
-      // Now, tell the device to send the whole command:
-      led.sendCommandToDevice();
-
-      // Sleep for an amount of time.
-      sleepUntilRepeat(commandDuration);
-
-      // Have we been told to stop yet?
-      if (checkRepeatFlag())
-      {
-        break;
-/*
-        // Ok, then we can quit now:
-        ++keypressCount;
-        QMutexLocker cifLocker(&commandIFMutex);
-        commandInFlight = false;
-        return;
-*/
-      }
-
-      ++repeatCount;
-    }
-
-    ++keypressCount;
     QMutexLocker cifLocker(&commandIFMutex);
     commandInFlight = false;
+    emit errorMessage("Key not defined in this keyset.");
+    return;
   }
-  catch (PIRException e)
+
+  // Construct the object that communicates with the device driver:
+  PIRInfraredLED led(carrierFrequency, dutyCycle);
+
+  connect(
+    &led,
+    SIGNAL(errorMessage(QString)),
+    this,
+    SIGNAL(errorMessage(QString)));
+
+  int repeatCount = 0;
+  int commandDuration = 0;
+  while (repeatCount < MAX_REPEAT_COUNT)
   {
-    emit commandFailed(e.getError().c_str());
+    // Now, throw together an RC5 protocol command string.
+
+    if (!preData.empty())
+    {
+      // For standard RC5, the "pre-data" contains the control portion,
+      // and the key contains only the 6-bit command portion.
+
+      // First, construct the control portion:
+      commandDuration += pushControlBits(led);
+
+      // Next, the key-command portion:
+      commandDuration += pushKeyCommandBits((*i).second, led);
+    }
+    else
+    {
+      // For non-standard RC5, the entire 13 bits are stuffed into the
+      // key portion, as all of them can vary:
+      commandDuration += pushNonStandardRC5((*i).second, led);
+    }
+
+    // Clear out the buffer, if necessary:
+    if (buffer)
+    {
+      led.addSingle(buffer);
+      commandDuration += buffer;
+
+      // probably unnecessary cleanup of buffer:
+      buffer = 0;
+      bufferContainsSpace = false;
+      bufferContainsPulse = false;
+    }
+
+    // Now, tell the device to send the whole command:
+    if (!led.sendCommandToDevice())
+    {
+      break;
+    }
+
+    // Sleep for an amount of time.
+    sleepUntilRepeat(commandDuration);
+
+    // Have we been told to stop yet?
+    if (checkRepeatFlag())
+    {
+      break;
+    }
+
+    ++repeatCount;
   }
+
+  ++keypressCount;
+  QMutexLocker cifLocker(&commandIFMutex);
+  commandInFlight = false;
 }
 
 
